.. python-tempestconf documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to python-tempestconf's documentation!
========================================================

python-tempestconf is a tool for automatic generation of tempest configuration
based on user's cloud.

Content:
--------

.. note::
    In Ocata release new features were presented. ``discover-tempest-config``
    is the new name of the **old** ``config_tempest.py`` script and it
    **accepts the same parameters.** More about the new features can be found
    `here <https://blogs.rdoproject.org/2017/02/testing-rdo-with-tempest-new-features-in-ocata/>`__

.. toctree::
   :maxdepth: 2

   overview
   install/index
   cli/index
   user/index
   admin/index
   contributor/index


* :ref:`search`

